{
 "metadata": {
  "name": ""
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "# Designing networks\n",
      "\n",
      "`Networks` are how Nengo encapsulates\n",
      "functionally complementary objects.\n",
      "Networks can contain\n",
      "ensembles, nodes, connection, even other networks.\n",
      "Models are often made much more readable\n",
      "my grouping objects into networks.\n",
      "Tools for visualizing networks\n",
      "will often use the network structure\n",
      "to produce cleaner images.\n",
      "\n",
      "Here, we will go over some general principles\n",
      "of network design. In the first section,\n",
      "we will go over these principles with a simple example.\n",
      "In the second section, we will apply\n",
      "these principles to a more complicated example.\n",
      "\n",
      "Briefly, the general principles we will\n",
      "go over in this tutorial are\n",
      "\n",
      "0. Group related objects in networks with `with`\n",
      "0. Reuse networks by defining functions\n",
      "0. Parameterize functions for more flexible reuse\n",
      "\n",
      "We will demonstrate these principles\n",
      "with a network consisting\n",
      "of two connected integrators\n",
      "as an example."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import numpy as np\n",
      "import matplotlib.pyplot as plt\n",
      "%matplotlib inline\n",
      "\n",
      "import nengo\n",
      "%load_ext nengo.ipynb\n",
      "from nengo.dists import Choice\n",
      "from nengo.utils.functions import piecewise\n",
      "from nengo.utils.ipython import hide_input\n",
      "def test_integrators(net):\n",
      "    with net:\n",
      "        piecewise_f = piecewise({0: 0, 0.2: 0.5, 1: 0, 2: -1, 3: 0, 4: 1, 5: 0})\n",
      "        piecewise_inp = nengo.Node(piecewise_f)\n",
      "        nengo.Connection(piecewise_inp, net.pre_integrator.input)\n",
      "        input_probe = nengo.Probe(piecewise_inp)\n",
      "        pre_probe = nengo.Probe(net.pre_integrator.ensemble, synapse=0.01)\n",
      "        post_probe = nengo.Probe(net.post_integrator.ensemble, synapse=0.01)\n",
      "    with nengo.Simulator(net) as sim:\n",
      "        sim.run(6)\n",
      "    plt.plot(sim.trange(), sim.data[input_probe], color='k')\n",
      "    plt.plot(sim.trange(), sim.data[pre_probe], color='b')\n",
      "    plt.plot(sim.trange(), sim.data[post_probe], color='g')\n",
      "hide_input()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "text": [
        "<IPython.core.display.Javascript at 0x7f2a606a10d0>"
       ]
      },
      {
       "html": [
        "\n",
        "        <a id=\"762635853\" href=\"javascript:toggle_input_762635853()\"\n",
        "          >Show Input</a>\n",
        "\n",
        "        <script type=\"text/javascript\">\n",
        "        var toggle_input_762635853;\n",
        "        (function() {\n",
        "            if (typeof jQuery == 'undefined') {\n",
        "                // no jQuery\n",
        "                var link_762635853 = document.getElementById(\"762635853\");\n",
        "                var cell = link_762635853;\n",
        "                while (cell.className.split(' ')[0] != \"cell\") {\n",
        "                    cell = cell.parentNode;\n",
        "                }\n",
        "                var input_762635853;\n",
        "                for (var i = 0; i < cell.children.length; i++) {\n",
        "                    if (cell.children[i].className.split(' ')[0] == \"input\")\n",
        "                        input_762635853 = cell.children[i];\n",
        "                }\n",
        "                input_762635853.style.display = \"none\"; // hide\n",
        "\n",
        "                toggle_input_762635853 = function() {\n",
        "                    if (input_762635853.style.display == \"none\") {\n",
        "                        input_762635853.style.display = \"\"; // show\n",
        "                        link_762635853.innerHTML = \"Hide Input\";\n",
        "                    } else {\n",
        "                        input_762635853.style.display = \"none\"; // hide\n",
        "                        link_762635853.innerHTML = \"Show Input\";\n",
        "                    }\n",
        "                }\n",
        "\n",
        "            } else {\n",
        "                // jQuery\n",
        "                var link_762635853 = $(\"a[id='762635853']\");\n",
        "                var cell_762635853 = link_762635853.parents(\"div.cell:first\");\n",
        "                var input_762635853 = cell_762635853.children(\"div.input\");\n",
        "                input_762635853.hide();\n",
        "\n",
        "                toggle_input_762635853 = function() {\n",
        "                    if (input_762635853.is(':hidden')) {\n",
        "                        input_762635853.slideDown();\n",
        "                        link_762635853[0].innerHTML = \"Hide Input\";\n",
        "                    } else {\n",
        "                        input_762635853.slideUp();\n",
        "                        link_762635853[0].innerHTML = \"Show Input\";\n",
        "                    }\n",
        "                }\n",
        "            }\n",
        "        }());\n",
        "        </script>\n",
        "    "
       ],
       "output_type": "pyout",
       "prompt_number": 1,
       "text": [
        "<IPython.core.display.HTML at 0x7f2a2807dd10>"
       ]
      }
     ],
     "prompt_number": 1
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## 1. Group related objects in networks with `with`\n",
      "\n",
      "All Nengo objects must be created\n",
      "in the context of some network.\n",
      "We use the `with` keyword to denote\n",
      "the network context in which\n",
      "a Nengo object is created.\n",
      "\n",
      "These `with` statements can be nested\n",
      "to group objects in appropriately named networks."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Example: two connected integrators\n",
      "#  (See integrator example network for more details)\n",
      "net = nengo.Network(label=\"Two integrators\")\n",
      "with net:\n",
      "    with nengo.Network() as pre_integrator:\n",
      "        pre_input = nengo.Node(size_in=1)\n",
      "        pre_ensemble = nengo.Ensemble(100, dimensions=1)\n",
      "        nengo.Connection(pre_ensemble, pre_ensemble, synapse=0.1)\n",
      "        nengo.Connection(pre_input, pre_ensemble, synapse=None, transform=0.1)\n",
      "    with nengo.Network() as post_integrator:\n",
      "        post_input = nengo.Node(size_in=1)\n",
      "        post_ensemble = nengo.Ensemble(100, dimensions=1)\n",
      "        nengo.Connection(post_ensemble, post_ensemble, synapse=0.1)\n",
      "        nengo.Connection(post_input, post_ensemble, synapse=None, transform=0.1)\n",
      "    nengo.Connection(pre_ensemble, post_input)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Test the integrators by giving piecewise input and plotting\n",
      "with net:\n",
      "    piecewise_f = piecewise({0: 0, 0.2: 0.5, 1: 0, 2: -1, 3: 0, 4: 1, 5: 0})\n",
      "    piecewise_inp = nengo.Node(piecewise_f)\n",
      "    nengo.Connection(piecewise_inp, pre_input)\n",
      "    input_probe = nengo.Probe(piecewise_inp)\n",
      "    pre_probe = nengo.Probe(pre_ensemble, synapse=0.01)\n",
      "    post_probe = nengo.Probe(post_ensemble, synapse=0.01)\n",
      "with nengo.Simulator(net) as sim:\n",
      "    sim.run(6)\n",
      "plt.plot(sim.trange(), sim.data[input_probe], color='k', label=\"input\")\n",
      "plt.plot(sim.trange(), sim.data[pre_probe], color='b', label=\"pre integrator\")\n",
      "plt.plot(sim.trange(), sim.data[post_probe], color='g', label=\"post integrator\")\n",
      "plt.legend(loc='best');"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAEACAYAAACwB81wAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nFApFHkEJvkKhUOQR/h8L/B7RLS7o1QAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a2805c110>"
       ]
      }
     ],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Note that the `with` statements\n",
      "are not just cosmetic;\n",
      "Nengo objects are stored\n",
      "in the network that they're constructed in."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "assert pre_input in pre_integrator\n",
      "assert pre_input not in net\n",
      "assert pre_integrator in net"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 4
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## 2. Reuse networks by defining functions\n",
      "\n",
      "Often, the same network is constructed\n",
      "more than once, resulting in duplicated code.\n",
      "We can reduce this code duplication\n",
      "by defining a function that\n",
      "creates the network and returns it.\n",
      "\n",
      "Even if you only use the network once,\n",
      "it can be helpful to define all of\n",
      "your subnetworks in functions\n",
      "to keep your code cleaner.\n",
      "Determining when a network\n",
      "should be defined in a function\n",
      "is informed by experience\n",
      "designing large networks\n",
      "and personal preference.\n",
      "\n",
      "### Store useful objects on the network\n",
      "\n",
      "A corollary to putting networks in functions\n",
      "is that any objects that you might want\n",
      "access to outside of that function\n",
      "should be stored on the network.\n",
      "Functions that create networks\n",
      "should only return that network.\n",
      "While all objects in that network\n",
      "are stored somewhere\n",
      "(e.g., ensembles are stored in a `net.ensembles` list),\n",
      "that list can be large and difficult to search.\n",
      "Therefore, we recommend storing objects\n",
      "on the network itself\n",
      "to make them accessible outside of the function."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Example: two connected integrators. Now with functions!\n",
      "def Integrator():\n",
      "    with nengo.Network() as integrator:\n",
      "        integrator.input = nengo.Node(size_in=1)\n",
      "        integrator.ensemble = nengo.Ensemble(100, dimensions=1)\n",
      "        nengo.Connection(integrator.ensemble, integrator.ensemble, synapse=0.1)\n",
      "        nengo.Connection(integrator.input, integrator.ensemble,\n",
      "                         synapse=None, transform=0.1)\n",
      "    return integrator\n",
      "\n",
      "net = nengo.Network(label=\"Two integrators\")\n",
      "with net:\n",
      "    net.pre_integrator = Integrator()\n",
      "    net.post_integrator = Integrator()\n",
      "    nengo.Connection(net.pre_integrator.ensemble, net.post_integrator.input)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 5
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# This function does the same as the previous example\n",
      "test_integrators(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAEACAYAAACwB81wAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nQtzE/wFDlxnolQrYTgAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24c2bcd0>"
       ]
      }
     ],
     "prompt_number": 6
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## 3. Parameterize functions for more flexible reuse\n",
      "\n",
      "Now that your network is created in a function,\n",
      "you can add parameters to your function\n",
      "to change how your network is constructed.\n",
      "This could be a huge change,\n",
      "allowing you to compare two different approaches\n",
      "to some component of your model,\n",
      "or it could something straightforward\n",
      "like changing the number of neurons\n",
      "in the ensembles in the network.\n",
      "\n",
      "Unlike other languages, Python allows you\n",
      "to add two different types of parameters:\n",
      "**positional** and **keyword** arguments.\n",
      "Positional arguments must be passed\n",
      "to your function.\n",
      "\n",
      "```python\n",
      ">>> def my_network(arg1, arg2):\n",
      "...     return \"%s %s\" % (arg1, arg2)\n",
      ">>> my_network()\n",
      "TypeError: my_network() takes exactly 2 arguments (0 given)\n",
      ">>> my_network(0, 0)\n",
      "'0 0'\n",
      "```\n",
      "\n",
      "Keyword arguments are assigned a default value,\n",
      "and so do not have to be passed to your function.\n",
      "\n",
      "```python\n",
      ">>> def my_network(arg1=0, arg2=0):\n",
      "...     return \"%s %s\" % (arg1, arg2)\n",
      ">>> my_network()\n",
      "'0 0'\n",
      ">>> my_network(1)\n",
      "'1 0'\n",
      "```\n",
      "\n",
      "Order does not matter if you explicitly\n",
      "label the argument in your function call.\n",
      "\n",
      "```python\n",
      ">>> my_network(arg2=2, arg1=1)\n",
      "'1 2'\n",
      ">>> my_network(arg2=2)\n",
      "'0 2'\n",
      "```"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Example: two connected integrators. Functions have parameters!\n",
      "def Integrator(n_neurons, dimensions, tau=0.1):\n",
      "    with nengo.Network() as integrator:\n",
      "        integrator.input = nengo.Node(size_in=dimensions)\n",
      "        integrator.ensemble = nengo.Ensemble(n_neurons, dimensions=dimensions)\n",
      "        nengo.Connection(integrator.ensemble, integrator.ensemble, synapse=tau)\n",
      "        nengo.Connection(integrator.input, integrator.ensemble,\n",
      "                         synapse=None, transform=tau)\n",
      "    return integrator"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 7
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Try 50 neuron ensembles\n",
      "net = nengo.Network(label=\"Two integrators\")\n",
      "with net:\n",
      "    net.pre_integrator = Integrator(50, 1)\n",
      "    net.post_integrator = Integrator(50, 1)\n",
      "    nengo.Connection(net.pre_integrator.ensemble, net.post_integrator.input)\n",
      "test_integrators(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAEACAYAAACwB81wAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nEIQYQQRfEAQhRvh/UCep82dw1aoAAAAASUVORK5CYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24c1ad50>"
       ]
      }
     ],
     "prompt_number": 8
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "# Try shorter tau (spoiler: it fails to integrate well)\n",
      "net = nengo.Network(label=\"Two integrators\")\n",
      "with net:\n",
      "    net.pre_integrator = Integrator(50, 1, tau=0.01)\n",
      "    net.post_integrator = Integrator(50, 1, tau=0.01)\n",
      "    nengo.Connection(net.pre_integrator.ensemble, net.post_integrator.input)\n",
      "test_integrators(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAXwAAAEACAYAAACwB81wAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24991990>"
       ]
      }
     ],
     "prompt_number": 9
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Longer example: double integrator network\n",
      "\n",
      "While the coupled integrator model above\n",
      "seems like a toy example,\n",
      "it is in fact a critical component\n",
      "of many models that capture\n",
      "neurophysiological and behavioral data.\n",
      "Let's looks at a more complicated network\n",
      "that uses coupled integrators,\n",
      "and show how the network design principles\n",
      "discussed above improve model organization.\n",
      "We will look at a simplified version\n",
      "of the network described in\n",
      "[Bekolay et al., 2014](http://compneuro.uwaterloo.ca/files/publications/bekolay.2014a.pdf).\n",
      "\n",
      "This network uses two coupled integrators\n",
      "in the context of a simple reaction time task.\n",
      "The subject presses down a lever,\n",
      "and should release that lever\n",
      "between 0.6 and 1.0 seconds later.\n",
      "In order to time the interval,\n",
      "the lever press starts the coupled integrators,\n",
      "which are tuned such that\n",
      "the second integrator should reach\n",
      "a high point by around 0.6 seconds.\n",
      "The second integrator\n",
      "effects the lever release.\n",
      "\n",
      "We'll start with a completely disorganized network.\n",
      "Even if you've read the paper,\n",
      "the code is quite hard to follow."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "with nengo.Network() as net:\n",
      "    tau = 0.1\n",
      "\n",
      "    pre_integrator = nengo.Ensemble(200, dimensions=2)\n",
      "    nengo.Connection(pre_integrator, pre_integrator[0],\n",
      "                     function=lambda x: x[0] * (1.0 - x[1]), synapse=tau)\n",
      "    post_integrator = nengo.Ensemble(200, dimensions=2)\n",
      "    nengo.Connection(post_integrator, post_integrator[0],\n",
      "                     function=lambda x: x[0] * (1.0 - x[1]), synapse=tau)\n",
      "    nengo.Connection(pre_integrator[0], post_integrator[0], transform=0.16)\n",
      "    press = nengo.Ensemble(30, dimensions=1,\n",
      "                           encoders=Choice([[1]]), intercepts=Choice([0.85]))\n",
      "    release = nengo.Ensemble(30, dimensions=1,\n",
      "                             encoders=Choice([[1]]), intercepts=Choice([0.85]))\n",
      "\n",
      "    nengo.Connection(press, pre_integrator[0], transform=tau * 3)\n",
      "    nengo.Connection(press, post_integrator[1], transform=-1 * 6)\n",
      "\n",
      "    nengo.Connection(post_integrator[0], release)\n",
      "    nengo.Connection(nengo.Node(lambda t: 1 if t < 0.2 else 0), press)\n",
      "\n",
      "    pr_press = nengo.Probe(press, synapse=0.01)\n",
      "    pr_release = nengo.Probe(release, synapse=0.01)\n",
      "    pr_pre_int = nengo.Probe(pre_integrator[0], synapse=0.01)\n",
      "    pr_post_int = nengo.Probe(post_integrator[0], synapse=0.01)\n",
      "\n",
      "def test_doubleintegrator(net):\n",
      "    with nengo.Simulator(net) as sim:\n",
      "        sim.run(1.4)\n",
      "    t = sim.trange()\n",
      "    plt.subplot(2, 1, 1)\n",
      "    plt.plot(t, sim.data[pr_press], c='b', label=\"Press\")\n",
      "    plt.plot(t, sim.data[pr_release], c='g', label=\"Release\")\n",
      "    plt.axvspan(0, 0.2, color='b', alpha=0.3)\n",
      "    plt.axvspan(0.8, 1.2, color='g', alpha=0.3)\n",
      "    plt.xlim(right=1.4)\n",
      "    plt.legend(loc=\"best\")\n",
      "    plt.subplot(2, 1, 2)\n",
      "    plt.plot(t, sim.data[pr_pre_int], label=\"Pre Integrator\")\n",
      "    plt.plot(t, sim.data[pr_post_int], label=\"Post Integrator\")\n",
      "    plt.xlim(right=1.4)\n",
      "    plt.legend(loc=\"best\")\n",
      "\n",
      "test_doubleintegrator(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nScBgMBjKMCYJGAwGQxnGJAGDwWAow/w/1SzkfgEA6KUAAAAASUVORK5CYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24cd39d0>"
       ]
      }
     ],
     "prompt_number": 10
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "Recall that the goal is to release the lever\n",
      "0.6-1.0 seconds after the press.\n",
      "The blue \"Press\" line in the upper plot\n",
      "represents the activity of neurons\n",
      "in motor cortex which effect the lever press.\n",
      "If we assume that the press occurs at 0.2 seconds,\n",
      "then the release window is between 0.8 and 1.2 seconds\n",
      "(shown in green).\n",
      "This will occur if the \"Post Integrator\" (see lower plot)\n",
      "is sufficiently high during this window.\n",
      "If you rerun the cell above several times,\n",
      "you can see that it usually achieves this,\n",
      "but not all of the time.\n",
      "\n",
      "Looking at the code, it's difficult to tell\n",
      "how we achieve this result.\n",
      "It's also difficult to see what parameters\n",
      "needed tweaking.\n",
      "Rather than just showing one parameter set that works,\n",
      "we should investigate reasonable ranges for\n",
      "each parameter.\n",
      "It would be easy to think that there is only\n",
      "one parameter, `tau`, in the model as presented,\n",
      "but this is not the case.\n",
      "\n",
      "Let's start with the first network design principle:\n",
      "group objects into networks with `with`."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "with nengo.Network() as net:\n",
      "    tau = 0.1\n",
      "\n",
      "    with nengo.Network() as medial_pfc:\n",
      "        with nengo.Network() as pre_integrator:\n",
      "            pre_ensemble = nengo.Ensemble(200, dimensions=2)\n",
      "            nengo.Connection(pre_ensemble, pre_ensemble[0],\n",
      "                             function=lambda x: x[0] * (1.0 - x[1]), synapse=tau)\n",
      "        with nengo.Network() as post_integrator:\n",
      "            post_ensemble = nengo.Ensemble(200, dimensions=2)\n",
      "            nengo.Connection(post_ensemble, post_ensemble[0],\n",
      "                             function=lambda x: x[0] * (1.0 - x[1]), synapse=tau)\n",
      "        nengo.Connection(pre_ensemble[0], post_ensemble[0], transform=0.16)\n",
      "    \n",
      "    with nengo.Network() as motor:\n",
      "        press = nengo.Ensemble(30, dimensions=1,\n",
      "                               encoders=Choice([[1]]), intercepts=Choice([0.85]))\n",
      "        release = nengo.Ensemble(30, dimensions=1,\n",
      "                                 encoders=Choice([[1]]), intercepts=Choice([0.85]))\n",
      "\n",
      "    nengo.Connection(press, pre_ensemble[0], transform=tau * 3)\n",
      "    nengo.Connection(press, post_ensemble[1], transform=-1 * 6)\n",
      "\n",
      "    nengo.Connection(post_ensemble[0], release)\n",
      "    nengo.Connection(nengo.Node(lambda t: 1 if t < 0.2 else 0), press)\n",
      "\n",
      "    pr_press = nengo.Probe(press, synapse=0.01)\n",
      "    pr_release = nengo.Probe(release, synapse=0.01)\n",
      "    pr_pre_int = nengo.Probe(pre_ensemble[0], synapse=0.01)\n",
      "    pr_post_int = nengo.Probe(post_ensemble[0], synapse=0.01)\n",
      "\n",
      "test_doubleintegrator(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24c1a7d0>"
       ]
      }
     ],
     "prompt_number": 11
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "This exhibits some of the hypotheses of this model;\n",
      "specifically, that the medial prefrontal cortex\n",
      "contains these integrators,\n",
      "and that they can be involved\n",
      "in control of motor actions.\n",
      "\n",
      "Let's do both of the remaining principles\n",
      "by making some parameterized functions\n",
      "to get a sense of all of the knobs\n",
      "that be be tweaked in this model."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def controlled_integrator(n_neurons, dimensions, tau=0.1):\n",
      "    with nengo.Network() as integrator:\n",
      "        integrator.ensemble = nengo.Ensemble(n_neurons, dimensions=dimensions + 1)\n",
      "        nengo.Connection(integrator.ensemble, integrator.ensemble[:dimensions],\n",
      "                         function=lambda x: x[:-1] * (1.0 - x[-1]), synapse=tau)\n",
      "    return integrator\n",
      "\n",
      "def medial_pfc(coupling_strength, n_neurons_per_integrator=200, tau=0.1):\n",
      "    with nengo.Network() as medial_pfc:\n",
      "        medial_pfc.pre = controlled_integrator(n_neurons_per_integrator, 1, tau)\n",
      "        medial_pfc.post = controlled_integrator(n_neurons_per_integrator, 1, tau)\n",
      "        nengo.Connection(medial_pfc.pre.ensemble[0], medial_pfc.post.ensemble[0],\n",
      "                         transform=coupling_strength)\n",
      "    return medial_pfc\n",
      "\n",
      "def motor_cortex(command_threshold, n_neurons_per_command=30):\n",
      "    with nengo.Network() as motor_cortex:\n",
      "        ens_args = {'dimensions': 1,\n",
      "                    'encoders': Choice([[1]]),\n",
      "                    'intercepts': Choice([command_threshold])}\n",
      "        motor_cortex.press = nengo.Ensemble(n_neurons_per_command, **ens_args)\n",
      "        motor_cortex.release = nengo.Ensemble(n_neurons_per_command, **ens_args)\n",
      "    return motor_cortex\n",
      "\n",
      "def double_integrator(mpfc_coupling_strength,\n",
      "                      command_threshold,\n",
      "                      press_to_pre_gain=3,\n",
      "                      press_to_post_control=-6,\n",
      "                      recurrent_tau=0.1,\n",
      "                      seed=None):\n",
      "    with nengo.Network(seed=seed) as net:\n",
      "        net.mpfc = medial_pfc(mpfc_coupling_strength)\n",
      "        net.motor = motor_cortex(command_threshold)\n",
      "        nengo.Connection(net.motor.press, net.mpfc.pre.ensemble[0],\n",
      "                         transform=recurrent_tau * press_to_pre_gain)\n",
      "        nengo.Connection(net.motor.press, net.mpfc.post.ensemble[1],\n",
      "                         transform=press_to_post_control)\n",
      "        nengo.Connection(net.mpfc.post.ensemble[0], net.motor.release)\n",
      "    return net\n",
      "    \n",
      "def test_doubleintegrator(net):\n",
      "    # Provide input and probe outside of network construction, for more flexibility\n",
      "    with net:\n",
      "        nengo.Connection(nengo.Node(lambda t: 1 if t < 0.2 else 0), net.motor.press)\n",
      "        pr_press = nengo.Probe(net.motor.press, synapse=0.01)\n",
      "        pr_release = nengo.Probe(net.motor.release, synapse=0.01)\n",
      "        pr_pre_int = nengo.Probe(net.mpfc.pre.ensemble[0], synapse=0.01)\n",
      "        pr_post_int = nengo.Probe(net.mpfc.post.ensemble[0], synapse=0.01)\n",
      "    with nengo.Simulator(net) as sim:\n",
      "        sim.run(1.4)\n",
      "    t = sim.trange()\n",
      "    plt.figure()\n",
      "    plt.subplot(2, 1, 1)\n",
      "    plt.plot(t, sim.data[pr_press], c='b', label=\"Press\")\n",
      "    plt.plot(t, sim.data[pr_release], c='g', label=\"Release\")\n",
      "    plt.axvspan(0, 0.2, color='b', alpha=0.3)\n",
      "    plt.axvspan(0.8, 1.2, color='g', alpha=0.3)\n",
      "    plt.xlim(right=1.4)\n",
      "    plt.legend(loc=\"best\")\n",
      "    plt.subplot(2, 1, 2)\n",
      "    plt.plot(t, sim.data[pr_pre_int], label=\"Pre Integrator\")\n",
      "    plt.plot(t, sim.data[pr_post_int], label=\"Post Integrator\")\n",
      "    plt.xlim(right=1.4)\n",
      "    plt.legend(loc=\"best\")\n",
      "\n",
      "net = double_integrator(mpfc_coupling_strength=0.16, command_threshold=0.85)\n",
      "test_doubleintegrator(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24d51cd0>"
       ]
      }
     ],
     "prompt_number": 12
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "While this does add some complexity and length,\n",
      "the effort is worth it,\n",
      "as we can now do simple parameters sweeps\n",
      "to investigate the effects\n",
      "of changing various parameters."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "for coupling_strength in (0.11, 0.16, 0.21):\n",
      "    net = double_integrator(mpfc_coupling_strength=coupling_strength,\n",
      "                            command_threshold=0.85,\n",
      "                            seed=0)\n",
      "    test_doubleintegrator(net)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n0YmZTsAwDKMTM52AYRhGJ/b/AwsFSxEujdgAAAAASUVORK5CYII=\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24b6d090>"
       ]
      },
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nyLhPOgAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a24503e10>"
       ]
      },
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAYEAAAEACAYAAABVtcpZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f2a243d3610>"
       ]
      }
     ],
     "prompt_number": 13
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "The `coupling_strength` changes how quickly\n",
      "the \"Post Integrator\" rises,\n",
      "which causes the release to occur\n",
      "at different times.\n",
      "Of the values tested,\n",
      "only a coupling strength of 0.16\n",
      "effects the release during the release window\n",
      "(for this particular network seed).\n",
      "\n",
      "We will looks at some more techniques\n",
      "for cleaning up this network code\n",
      "and making it more flexible\n",
      "in \"Additional tips and tricks for designing networks\"."
     ]
    }
   ],
   "metadata": {}
  }
 ]
}